@@ -1,6 +1,6 @@
 package Org::Element::TableRow;
 BEGIN {
-  $Org::Element::TableRow::VERSION = '0.03';
+  $Org::Element::TableRow::VERSION = '0.04';
 }
 # ABSTRACT: Represent Org table row
 
@@ -9,12 +9,14 @@ use Moo;
 extends 'Org::Element::Base';
 
 
-sub children_as_string {
+sub as_string {
     my ($self) = @_;
-    my @res;
-    push @res, map { ("|", $_->as_string) } @{ $self->children };
-    push @res, "\n";
-    join "", @res;
+    return $self->_str if defined $self->_str;
+
+    join("",
+         "|",
+         join("|", map {$_->as_string} @{$self->children}),
+         "\n");
 }
 
 
@@ -27,7 +29,7 @@ Org::Element::TableRow - Represent Org table row
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 DESCRIPTION
 
@@ -41,7 +43,7 @@ Must have L<Org::Element::TableCell> instances as its children.
 
 =head1 METHODS
 
-=for Pod::Coverage children_as_string
+=for Pod::Coverage as_string
 
 1;
 __END__
