@@ -4,37 +4,15 @@ use 5.010;
 use strict;
 use warnings;
 
+use Org::Dump;
+
 sub test_parse {
     my %args = @_;
 
     my $fe = $args{filter_elements};
 
     subtest $args{name} => sub {
-        my @elems;
         my $orgp = Org::Parser->new();
-        if ($args{handler}) {
-            $orgp->handler($args{handler});
-        } elsif ($fe) {
-            $orgp->handler(
-                sub {
-                    my ($orgp, $ev, $args) = @_;
-                    return unless $ev eq 'element';
-                    my $el     = $args->{element};
-                    my $eltype = ref($el);
-                    my $fetype = ref($fe);
-                    if ($fetype eq 'Regexp') {
-                        return unless $eltype =~ $args{filter_elements};
-                    } elsif ($fetype eq 'CODE')  {
-                        return unless $fe->($el);
-                    } elsif (!$fetype) {
-                        return unless $eltype eq $args{filter_elements};
-                    } else {
-                        die "BUG: filter_elements cannot be a $fetype";
-                    }
-                    push @elems, $el;
-                });
-        }
-
         my $res;
         eval {
             if ($args{doc}) {
@@ -50,11 +28,31 @@ sub test_parse {
         my $eval_err = $@;
 
         if ($args{dies}) {
-            ok($eval_err, "dies");
+            ok($eval_err, "dies") or diag(Org::Dump::dump_element($res));
+            return;
         } else {
             ok(!$eval_err, "doesnt die") or diag("died with msg $eval_err");
         }
 
+        my @elems;
+        $res->walk(
+            sub {
+                my ($el)   = @_;
+                my $eltype = ref($el);
+                my $fetype = ref($fe);
+                if ($fetype eq 'Regexp') {
+                    return unless $eltype =~ $args{filter_elements};
+                } elsif ($fetype eq 'CODE')  {
+                    return unless $fe->($el);
+                } elsif (!$fetype) {
+                    return unless $eltype eq $args{filter_elements};
+                } else {
+                    die "BUG: filter_elements cannot be a $fetype";
+                }
+                push @elems, $el;
+            }
+        ) if $fe;
+
         if (defined $args{num}) {
             is(scalar(@elems), $args{num}, "num=$args{num}");
         }
